@@ -6,7 +6,7 @@
 #            you can capture and anlyze.
 #
 
-__version__ = "0.1"
+__version__ = "0.3"
 
 import sys
 import os
@@ -31,41 +31,47 @@ if __name__ == "__main__":
     p.add_option(
         '-b', '--entries_per_block', dest='entries_per_block', type='int',
         help="specify number of entries in priority block", default=10)
+    p.add_option(
+        '-t', '--tables', dest='output_target_tables',
+        help="specify the tables to be output.")
     p.add_option(
         '-v', '--verbose', dest='verbose', action="store_true", default=False,
         help="verbose output")
-    p.add_option(
-        '-s', '--output_summary', dest='output_summary', action="store_true", default=False,
-        help="output summary informations")
     p.add_option(
         '-d', '--debug', dest='debug', action="store_true", default=False,
         help="debug output")
     g1 = OptionGroup(p, "Output Flags")
     g1.add_option(
-        '--enable_resubmit_loop_output', dest='resubmit_loop_output',
+        '--enable_output_resubmit_loop', dest='output_resubmit_loop',
         action="store_true", default=True,
         help="enable the output of the 'resubmit to start' that re-evaluate at the same table")
     g1.add_option(
-        '--disable_resubmit_loop_output', dest='resubmit_loop_output',
+        '--disable_output_resubmit_loop', dest='output_resubmit_loop',
         action="store_false", default=True,
         help="disable the output of the 'resubmit to start' that re-evaluate at the same table")
     g1.add_option(
-        '--enable_note_output', dest='note_output',
+        '--enable_output_summary', dest='output_summary',
         action="store_true", default=True,
-        help="enable the output of the 'note action'")
+        help="enable the output of the summary informations")
     g1.add_option(
-        '--disable_note_output', dest='note_output',
+        '--disable_output_summary', dest='output_summary',
         action="store_false", default=True,
-        help="disable the output of the 'note action'")
+        help="disable the output of the output summary informations")
     p.add_option_group(g1)
     (opts, args) = p.parse_args()
 
     util = CommonUtils(opts)
 
+    output_target_tables = []
+    if  opts.output_target_tables is not None:
+        output_target_tables = opts.output_target_tables.split(',')
+        
     if  opts.formatter == "graphviz":
         formatter = GraphvizTBFormatter(util)
+        formatter.set_output_target_tables(output_target_tables)
         formatter.set_entries_per_block(opts.entries_per_block)
         formatter.set_output_summary(opts.output_summary)
+        formatter.set_output_resubmit_loop(opts.output_resubmit_loop)
     elif  opts.formatter == "csv":
         formatter = CSVFormatter(util)
     elif  opts.formatter == "tsv":
